import pytest
from pyfakefs.fake_filesystem import FakeFilesystem


@pytest.fixture
def test_host_cert_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIC+zCCAeMCFCTQmEgIErlEb0dap4sFeCkmQyYbMA0GCSqGSIb3DQEBCwUAMDkx
CzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxGTAXBgNVBAMMEFRlc3QgQ2Vy
dGlmaWNhdGUwIBcNMjEwNTIwMTgxMzA1WhgPMjEyMTA0MjYxODEzMDVaMDkxCzAJ
BgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxGTAXBgNVBAMMEFRlc3QgQ2VydGlm
aWNhdGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7lEBKkJu9XWt6
1wLinWPnKZydd/sz1pfzROa8IGtKJTB8AKEIZEJ68rz8s03gTPHlpIHxjOfmf+cR
4FqhA2iRTwenEFXc+hb3m0bBKg/w1DPtgFflJJXHSCH8jG/YiKEXWPyLImmy36/A
97t0v2JUtbwCA1lFCoKjEbwbUT7znvRe0gJUyy8EiTPJlvTe6jiohNzQdV4B4odx
ZCv36L8vHbnKUjvzWwLGXPgqKCheM/X1Trrl8UtmTf/z99URS5++ALhRnaz5thHL
SGtu84k1Re1RCMknz6QeqF68xiEKsJ+s2f6XKOGy3vLmVslXqJKgfYyVi1S15loJ
pAVH7+r1AgMBAAEwDQYJKoZIhvcNAQELBQADggEBAKT7o2pPlqA5RduFq9Gh+k2q
uz5UeHjC2ot8g+KWEDT4WtEs0dCHhj4kp1Wp7vZ5dRXc2GMqHUbmbMdt4jGkoAY2
Ra33pzyS3vZJbfGjnwxbc6GgAlhKPbEzI1D9gb244oPr9UdB9seCqVYoTNjYXfp0
KIEA7J0GX/xxo2ZXM+Ol9isI1IhUIjnymof4j0TNptHQTk2k5v0T+DXpeA2ORWLM
hd0BJgkH4hHdAs+wv7oEJMd0h2dt+lHgOuFpMpJkgTqcS27HcydoXTq8p/ooDJgy
FChTOV1iGYEywbsNByrC3pMXn/D4nC9O5a02OfTmOIQqBCcAzaGs6f8h08r+R4s=
-----END CERTIFICATE-----"""


@pytest.fixture
def test_host_cert_subject() -> str:
    return "/C=US/O=Globus/CN=Test Certificate"


@pytest.fixture
def test_host_cert_file(fs: FakeFilesystem, test_host_cert_data: str) -> str:
    name = "hostcert.pem"
    with open(name, "w") as f:
        print(test_host_cert_data, file=f)

    return name


@pytest.fixture
def test_user_cert_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIID+jCCAeKgAwIBAgIBATANBgkqhkiG9w0BAQsFADArMQswCQYDVQQGEwJVUzEP
MA0GA1UECgwGR2xvYnVzMQswCQYDVQQDDAJDQTAeFw0yMjExMjkxNjQyNTFaFw0y
MzExMjkxNjQyNTFaMD8xCzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxCzAJ
BgNVBAsMAkNBMRIwEAYDVQQDDAlVc2VyIENlcnQwggEiMA0GCSqGSIb3DQEBAQUA
A4IBDwAwggEKAoIBAQDOPiha69iyAAuqEvsJfYg+0lm7QrxsZG/gMrv7k7dCiFax
+d01sIjNH2vjZTG1sYE9PymPQHSgwUE9Cz/GHQZGXnrmUyQ0hvzw107uRs/v9QNX
BCmOlEYTKp1lo4JNPTaaMn6f1vavfrh5FymTt8xtSk2sG0iYrwtLtE9sb+R5NjZe
43G7j6/yT88ioXFa7BKvOerR9AL/1fyYkiehksiq2W7w+sKIEQv5Nw7PGMfndk52
T7frwh75mRlrYyT+zvAzpIsfb0QYTPJIkeBEGvwTRsXL3JV5uMcf4rnJz/QudEqJ
Qgi0UITprs6twvVzQ62mdqUx9EU4amQK5U1SG+rtAgMBAAGjFTATMBEGCWCGSAGG
+EIBAQQEAwIE8DANBgkqhkiG9w0BAQsFAAOCAgEAQwLIy4oevEM3j17wmRHlBCuY
KwpQXIHMlDooIziLdcUU0RfRHgX2WmbDSG8Zf3VvrtYrMhLVchGEzp3FxSUIobb8
kpXj9/Rocl3DAU2QuKQOpZwlKyCVSrGzytzT/sd+Djy1lD/I47K9mWLBrJ9wYo1e
NoCyS8Z4xSWwfwoDfGWe95kQXxdal2un2ehsYNVzYInXxRO4eJjdt9pG/BYHpCSh
XBMP6FWgQ9+MJSWiQz2dFrbdp2wbPQjFATWhQmXE1T0qwwfrgfd2ZFPe6m1qlfmd
iY5yFMglmMnYkNF1HscXYdhCu5CdeaNRhosmDkVvLAcC5dDw/M2hKRZZMA2h7JAS
vZO0OYJJZ8tLgLrXoonuEeR77hndTjjVnHHBfaQfGr+lPihAAHCpQRRGC01L7wAZ
jrKukXM2sqzN1zyWr6UomquXeSYC5povGfs67Sk+Ow8WkjV4HwLtWHLVwJNSw+B6
fNm7IVDe60l4nrjk5mYa4S8MComb9J4yLctKWx+VGqdL6jcnGH6w+2+7A2hDZM+M
bWB+2XjzmOq7REBAYq9dQ/UPcGehdyj4OHtA9qrHHQig5+w5dVZRJfHLTvNHGIse
yL9R0xdILmZIoocvwY//NeL8+sMGH2RJKzlb6LqKsYIJnuxrLhCdItX1w3bXlKUX
/PrOBgSbIO8Z+QhWuEw=
-----END CERTIFICATE-----"""


@pytest.fixture
def test_user_cert_proxy_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIDMjCCAhqgAwIBAgIEPt46jTANBgkqhkiG9w0BAQsFADA/MQswCQYDVQQGEwJV
UzEPMA0GA1UECgwGR2xvYnVzMQswCQYDVQQLDAJDQTESMBAGA1UEAwwJVXNlciBD
ZXJ0MB4XDTIyMTEyOTE2MzkxM1oXDTIyMTEzMDA0NDQxM1owVDELMAkGA1UEBhMC
VVMxDzANBgNVBAoMBkdsb2J1czELMAkGA1UECwwCQ0ExEjAQBgNVBAMMCVVzZXIg
Q2VydDETMBEGA1UEAxMKMTA1NDc1MTM3MzCCASIwDQYJKoZIhvcNAQEBBQADggEP
ADCCAQoCggEBAJ9qAwadyupXERH8xXi14aWmdyRcTu/LAc3YIEgYLWPNvm3b3KyV
FVAQ74vsJwE7l1NC3P4Yrqk+qmbxnEESM0j6rLExYN9Kzy1rPrRfz6DTkbzx+Hx5
UfaUfdGkExOOpkeK/VsM/WLMb3IwRyNRz2U1nfhv8K6No4ZqU6mYoJcMxwPUQJX+
CO4hjyhMvjwqTKbFJATpgN6ccW1QXbITHl4inHI2zZuVMbZEyGuLzf+2nJziEXO1
i6N1sMU5EWsU9JpEujzbCl/N/Jml06hLm+6PkZoqv75h0tkk1iR1jpv9nQyQmSCC
ffoHIdtRJovbBGxUwow6ntO7RnGTX9bLybECAwEAAaMhMB8wHQYIKwYBBQUHAQ4B
Af8EDjAMMAoGCCsGAQUFBxUBMA0GCSqGSIb3DQEBCwUAA4IBAQDJl55w/BmNBkka
neVwVpQUjae+QYr5Mm+pFVKddyogIb+lkWMfMg3DrsV9YDRgclVA9fUmYuQq9L/w
U+xURvC5U/37Z8B5RyEP7G/P/kYQXMDSVLIaU4xWpj7otC2n5mHL8E3Q712NzJ5b
A+6uprOOwyt3f3XvO6YkloJ44IpuDO9GLP1F9KrZPgGNDQJqUyhVEi5aPEchUTio
fCewrsVxXpbkEQNfF8JjVA/uYMb8LVYFSs/XLlfKRzwMUwaols6jh47WqZzFtcVa
EORgNbw0jNG7QRrpqvkusfnTCM2Y18142HeNmWIvrQycTorz+dKn4oN8J2H6be/g
jcpvx19r
-----END CERTIFICATE-----
-----BEGIN CERTIFICATE-----
MIID+jCCAeKgAwIBAgIBATANBgkqhkiG9w0BAQsFADArMQswCQYDVQQGEwJVUzEP
MA0GA1UECgwGR2xvYnVzMQswCQYDVQQDDAJDQTAeFw0yMjExMjkxNjQyNTFaFw0y
MzExMjkxNjQyNTFaMD8xCzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxCzAJ
BgNVBAsMAkNBMRIwEAYDVQQDDAlVc2VyIENlcnQwggEiMA0GCSqGSIb3DQEBAQUA
A4IBDwAwggEKAoIBAQDOPiha69iyAAuqEvsJfYg+0lm7QrxsZG/gMrv7k7dCiFax
+d01sIjNH2vjZTG1sYE9PymPQHSgwUE9Cz/GHQZGXnrmUyQ0hvzw107uRs/v9QNX
BCmOlEYTKp1lo4JNPTaaMn6f1vavfrh5FymTt8xtSk2sG0iYrwtLtE9sb+R5NjZe
43G7j6/yT88ioXFa7BKvOerR9AL/1fyYkiehksiq2W7w+sKIEQv5Nw7PGMfndk52
T7frwh75mRlrYyT+zvAzpIsfb0QYTPJIkeBEGvwTRsXL3JV5uMcf4rnJz/QudEqJ
Qgi0UITprs6twvVzQ62mdqUx9EU4amQK5U1SG+rtAgMBAAGjFTATMBEGCWCGSAGG
+EIBAQQEAwIE8DANBgkqhkiG9w0BAQsFAAOCAgEAQwLIy4oevEM3j17wmRHlBCuY
KwpQXIHMlDooIziLdcUU0RfRHgX2WmbDSG8Zf3VvrtYrMhLVchGEzp3FxSUIobb8
kpXj9/Rocl3DAU2QuKQOpZwlKyCVSrGzytzT/sd+Djy1lD/I47K9mWLBrJ9wYo1e
NoCyS8Z4xSWwfwoDfGWe95kQXxdal2un2ehsYNVzYInXxRO4eJjdt9pG/BYHpCSh
XBMP6FWgQ9+MJSWiQz2dFrbdp2wbPQjFATWhQmXE1T0qwwfrgfd2ZFPe6m1qlfmd
iY5yFMglmMnYkNF1HscXYdhCu5CdeaNRhosmDkVvLAcC5dDw/M2hKRZZMA2h7JAS
vZO0OYJJZ8tLgLrXoonuEeR77hndTjjVnHHBfaQfGr+lPihAAHCpQRRGC01L7wAZ
jrKukXM2sqzN1zyWr6UomquXeSYC5povGfs67Sk+Ow8WkjV4HwLtWHLVwJNSw+B6
fNm7IVDe60l4nrjk5mYa4S8MComb9J4yLctKWx+VGqdL6jcnGH6w+2+7A2hDZM+M
bWB+2XjzmOq7REBAYq9dQ/UPcGehdyj4OHtA9qrHHQig5+w5dVZRJfHLTvNHGIse
yL9R0xdILmZIoocvwY//NeL8+sMGH2RJKzlb6LqKsYIJnuxrLhCdItX1w3bXlKUX
/PrOBgSbIO8Z+QhWuEw=
-----END CERTIFICATE-----"""


@pytest.fixture
def test_user_cert_pre_rfc_proxy_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIDMzCCAhugAwIBAgIENaOIPDANBgkqhkiG9w0BAQsFADA/MQswCQYDVQQGEwJV
UzEPMA0GA1UECgwGR2xvYnVzMQswCQYDVQQLDAJDQTESMBAGA1UEAwwJVXNlciBD
ZXJ0MB4XDTIyMTEyOTE2NDAwM1oXDTIyMTEzMDA0NDUwM1owUzELMAkGA1UEBhMC
VVMxDzANBgNVBAoMBkdsb2J1czELMAkGA1UECwwCQ0ExEjAQBgNVBAMMCVVzZXIg
Q2VydDESMBAGA1UEAxMJODk5OTA5NjkyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8A
MIIBCgKCAQEAtdw+A2pmrPhhx0rAmDOmKkMiCEQNg671keR2Euek34zvkCluadLL
21LRWTY4IyI4leau8B8Q7najvOmI6n4P1BonJjVhop0kJVDG1MNkfPltvoI97jUS
pXvmhnAIcS/qf81e+XXlfmbek6Z5uK2eqFJHPcSIJIVdj34MXgK/rxepKSUeH3TZ
OHZBLOl1pYIKf0NKf36V7xH7JcAcke3qM6bVP3MmePlR4EViuNT2ZgTtD/VuLNH6
FG4X0XdUbEcoGv5ry1mQd0/t9Zb/imfhmsQ3EmLAnpPSZW3LkdpaV7Rw9zB4zy+x
Y2GlqGemwnoAWtsFX63e6yfvbTubAZ4HJwIDAQABoyMwITAfBgorBgEEAZtQAYFe
AQH/BA4wDDAKBggrBgEFBQcVATANBgkqhkiG9w0BAQsFAAOCAQEAjLaKG/1ocemw
6zGNmlXHy2OcyKSv8qZvpzTT0JX8Ki2dRra9pHiYnuk0v7tSUn12WZzupBZVk3NL
mWNgqLGATxZd52OJMgR4xbajkeZzhnhgSYXtmeMRua24tzsXzwtLuT0hwkiB0QzD
XaPpaQZ+jYif/LNOUOXGJLv2HI3r/zsMAyfQq00lCsxRNkcahMf3TPVEjH8NIGL7
wFSRtEAI81JRZNaAcUvmzGAF4k5o6wavH4u2w0LyOXApnUd7c1f0z4bm9XBQlFkA
Td7pgxbdXt5KSpil+QtEQJaIyQW6w2+V5So3R3tQ1m7E8CGUY5QO9xmTmz7KDtvR
l6m/jO782Q==
-----END CERTIFICATE-----
-----BEGIN CERTIFICATE-----
MIID+jCCAeKgAwIBAgIBATANBgkqhkiG9w0BAQsFADArMQswCQYDVQQGEwJVUzEP
MA0GA1UECgwGR2xvYnVzMQswCQYDVQQDDAJDQTAeFw0yMjExMjkxNjQyNTFaFw0y
MzExMjkxNjQyNTFaMD8xCzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxCzAJ
BgNVBAsMAkNBMRIwEAYDVQQDDAlVc2VyIENlcnQwggEiMA0GCSqGSIb3DQEBAQUA
A4IBDwAwggEKAoIBAQDOPiha69iyAAuqEvsJfYg+0lm7QrxsZG/gMrv7k7dCiFax
+d01sIjNH2vjZTG1sYE9PymPQHSgwUE9Cz/GHQZGXnrmUyQ0hvzw107uRs/v9QNX
BCmOlEYTKp1lo4JNPTaaMn6f1vavfrh5FymTt8xtSk2sG0iYrwtLtE9sb+R5NjZe
43G7j6/yT88ioXFa7BKvOerR9AL/1fyYkiehksiq2W7w+sKIEQv5Nw7PGMfndk52
T7frwh75mRlrYyT+zvAzpIsfb0QYTPJIkeBEGvwTRsXL3JV5uMcf4rnJz/QudEqJ
Qgi0UITprs6twvVzQ62mdqUx9EU4amQK5U1SG+rtAgMBAAGjFTATMBEGCWCGSAGG
+EIBAQQEAwIE8DANBgkqhkiG9w0BAQsFAAOCAgEAQwLIy4oevEM3j17wmRHlBCuY
KwpQXIHMlDooIziLdcUU0RfRHgX2WmbDSG8Zf3VvrtYrMhLVchGEzp3FxSUIobb8
kpXj9/Rocl3DAU2QuKQOpZwlKyCVSrGzytzT/sd+Djy1lD/I47K9mWLBrJ9wYo1e
NoCyS8Z4xSWwfwoDfGWe95kQXxdal2un2ehsYNVzYInXxRO4eJjdt9pG/BYHpCSh
XBMP6FWgQ9+MJSWiQz2dFrbdp2wbPQjFATWhQmXE1T0qwwfrgfd2ZFPe6m1qlfmd
iY5yFMglmMnYkNF1HscXYdhCu5CdeaNRhosmDkVvLAcC5dDw/M2hKRZZMA2h7JAS
vZO0OYJJZ8tLgLrXoonuEeR77hndTjjVnHHBfaQfGr+lPihAAHCpQRRGC01L7wAZ
jrKukXM2sqzN1zyWr6UomquXeSYC5povGfs67Sk+Ow8WkjV4HwLtWHLVwJNSw+B6
fNm7IVDe60l4nrjk5mYa4S8MComb9J4yLctKWx+VGqdL6jcnGH6w+2+7A2hDZM+M
bWB+2XjzmOq7REBAYq9dQ/UPcGehdyj4OHtA9qrHHQig5+w5dVZRJfHLTvNHGIse
yL9R0xdILmZIoocvwY//NeL8+sMGH2RJKzlb6LqKsYIJnuxrLhCdItX1w3bXlKUX
/PrOBgSbIO8Z+QhWuEw=
-----END CERTIFICATE-----"""


@pytest.fixture
def ca_cert_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIFHjCCAwagAwIBAgIJAKnj4NlayUStMA0GCSqGSIb3DQEBCwUAMCsxCzAJBgNV
BAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxCzAJBgNVBAMMAkNBMB4XDTIyMTEyOTE2
NDIwOFoXDTI3MTEyODE2NDIwOFowKzELMAkGA1UEBhMCVVMxDzANBgNVBAoMBkds
b2J1czELMAkGA1UEAwwCQ0EwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
AQDRRp6FD9wkWrHmiIBtAiCMxN29tNDPdKAZLPFMMZiGBnt6+HlhrpZ0QuvX/Fu/
scC8IApXW76X/U/8o5JwxXCePGNxNYdav+XcgRJE8+s9lFHsI4xFZeQPfTDEW8ME
+tQQ1dV3Ht4mMq9RIgMzXVsqPq8Kr0jabPJhEaec0OfL61WbTF30OncVnpWwzrKN
RTfK2aPHB16CI73EaTFg2kqMlR1zDo4SecpDApyK0iy/pWj1bHAJLB1hKSMI22pd
7CrS5M4CAHnPQQtY0IMQoRr3LbHUYrcgnTila9+EfWpmBlqjNvcPLPer0qq5FjLZ
n60x1S/QNSwJDRDAEqRi/hFtzBqHMWSBn6TMTbTWECtR1ko+JPV9HkzJO5o46NJQ
zcHPLtdGwUhUtMOt5jVwTU0Rh5ixxzJL/sSmtuzJrZYo6DoDbJmc4CDDzFJimibJ
QvNwqLwpPsNWX/mqIWwFQkBugx8BSw0lsD6npwZ6wITSYe22dA270q8WEwqlRjI6
+OmWCAlxl27eA2lIpyJkWCZnyqZEzIBCRdsET66pL6o7lImGUvMbx4SpMdutjtxf
P6vk3TDS4itnwDvCSjWo4wLkPSCJpBOYte2aE4UOylLqaGq7ECh1pfJ+HdfwvMGt
5bn6Wv3syrOI7lnxsBU6RXwB2cKMkRhC4L2V2pM3KNS1hwIDAQABo0UwQzAPBgNV
HRMBAf8EBTADAQH/MB0GA1UdDgQWBBQseRY9OyHBiTDm9vtkkOPtZy2OlzARBglg
hkgBhvhCAQEEBAMCAAcwDQYJKoZIhvcNAQELBQADggIBAHKijUqtFV3DM2G/FM/7
F3OlzCZ8/smS0MiQ3LNQBdYXKxFEVp+8qIxP6Rr/R0eHvB5SMzdiTLQPtsL59V92
X04uq7A3WLm7Oa3R1ESdey77ZG91/sG/Rg48InHHq64KmrtmAxWQYRhTAqZW5Jy1
1OqC+BdIsv8Jl/e88lb4tXX/BcCTc4u4Nn+TPRTe8Mv7r5+GYplNiPUKKpdNh8uL
YBKaNcjZK4F1RhXJV3wTWHZHaySe65t6KEPFUB2FAESpyPoZ2GiaNlFWtuAvrZin
OYtB1I4zKLArnwud1ZrHYtnF5DwvmgrsPatao33YPhHTPl+47mg9FYzBFVXfY7ez
KBCl2iZ1yA4B9M7KNV1SX/cZnwL+YbkRNX+T+rhF6dqFTwDokcBWE8ed9Y87ee3F
f+bPLJECcSGtWTgoBjG/iqEcZTDueplQGkYGcuZRWtMe6ZxR/eTofAsia/ZZkwhH
pIA+4B1ZW9CFP3WtxpuP3cLSfAlO8YCnw9boZnWr1Qz+6xU5YWljR0S5IwNTyEn1
JTjBE1wP9WqcJkvJHObcNx5HT9oOG1oo3A0fFnSYpo5BPC8K6HoNerZRt0n+A1bx
fYgf8se8ghrnQlybelLEBSV677ka6g7Qy5AbbINEEHCXTkeR1m0JDJHmWh0/tFPk
NgJ9BKo/AR5MfIOY0fOcr4B1
-----END CERTIFICATE-----"""


@pytest.fixture
def test_user_cert_subject() -> str:
    return "/C=US/O=Globus/OU=CA/CN=User Cert"


@pytest.fixture
def test_user_subject_hash() -> str:
    return "35a688bd"


@pytest.fixture
def test_private_key_data() -> str:
    return """\
-----BEGIN RSA PRIVATE KEY-----
MIIEowIBAAKCAQEA0ykWCGVwXczyyhejBfZaB7uLEQj1oznUV/KhCd8MeFLM1sAb
xVJAY0yHKUncKXf/su27cTwgG3N4qsRzuT5qcbusiM1nh3mRiUyzAdXaxy/GbZW1
Gbhw2+/F27Yr/R2GMKMGP8DgM92HtKVYcLT71zerBZA86s1UTWEew0pKUpn0rCTM
oGgaijuBKvViIBqrlfCPsWg6te68nVt6Lk/nSPlzlXhRuXtJTdhaDoZO15BroEDs
xRi9Reo9I8pm3FKEoKaLBKIlwRqfedEJGkCEK12Iu6aAVc7N3zEU7lFyCrtedDI2
zlWpwA9znHSkpFHb9CxDggDqEtLSVZemEqdZCwIDAQABAoIBAGl9CQjAxFXX4SKc
lFCSNX/PbTXhZ/VXGoGlMFYiG7SwiKxv5G+7G3d/77XstBPzYsYchZuYEeIk2Y9V
/Qn56GtQ+myNUL8ZOF+C9ZphH56Ke3Kba5Gh1p/JNOsCIw+cBEGf76tBy7+dWAIi
5//GKlnl8YYh/IzAbvEJJ7kgD+kbH55sjtk/RdIj+EEA09ooj29kfVQEqXD0NaDS
JPy+NMB+PJxZQMIsmuH7OCAnAcVkIlqdlwc7AfNx6He+UYypkrJLyNijf4Kmklxl
yGh23WyFIxooVdppg+wiTyFwVrZSggdZQFhKvNn7b4wH4i+0EeS/fWzvq7v3Eccs
GqGUFKECgYEA98Jan4FI4ilq7zk1T1lqEowEHpbJzG7gJ9D3d7kdS6xEgA06FhW+
6TSvWAJ+Z8IwoHTYrAle+CZLpkE96l9avToL3oa3ME6+J9vtLqn8izZS+k9NXYol
0wF4STiX/gEHhBUXV4t275W6I82mvPXFP24+3FxaZXItkpRE11gPYScCgYEA2i8Y
+9C51BALUgHRbNxshvYQP37AWsePY8+dK1hd6hh6DHCFUPmMa35698MJq5+SNrVu
jtMq033bfGFyrEF0g/gditW1eXLwbfXWzfkLWMs8Sg7NzEs+JtQKNv2yQil4XKfk
O+wNkiAigaLFaWO/vINKDxGH7JgdxqJYRFDzb30CgYBRFUIjQWRg370nXUmdFl4o
g7o1aJPSW9bwMOtMO0DjKxWf8rQ31hYMrDlWTDqiKmNPn+3pH4f9HktTtbZVpa9E
jmKkCOKa5KpG0SrmQqtrw/OUB7ACFNwcGjcLf4H+lsem6mAhPntGHXI1lXAkFyre
f24DIBZVbPCNMAj3kNI3sQKBgB0rktGH9HBPvNO3/oHpbnEU0NNMZPc+GwOjLEYx
SE0V/KtRF+Hdm1J71IDviIlzih7aXu+ld+JSv1d/x88T6ToDoB+BtwOHxHFPHurm
0weKFINqO0WHAcY7Lypu/LgvxzHMGI2SX7YbqcFfO7l9ZpMTkoE1PND6/XAjIF3x
3LoZAoGBAJ7U0QEv6PHg2lHiu7SypwzUoDLNd04YrA2PwmoGje8v2EDD3+LJ07WW
V9H5a6jUn1ijCHZ4JxaJL1g66ZHU9eYXtyQS0k8GfIfUccVQ6NNgsdLEEn9toSux
gl2AZ43o5dOXAZiFzjssyxK3KXu8b3t98XB0ZMvYj896sJvz7Jn3
-----END RSA PRIVATE KEY-----"""


@pytest.fixture
def test_private_key_file(fs: FakeFilesystem, test_private_key_data: str) -> str:
    name = "private_key.pem"

    with open(name, "w") as f:
        print(test_private_key_data, file=f)

    return name
