from typing import List, Optional, Tuple

import pytest

from gcs_migration.parsers import parse_restrict_paths
from gcs_migration.typing.gcs_documents import PathRestrictionsDict


@pytest.mark.parametrize(
    "read", [("", []), ("R/", ["/"]), ("R/some,R/other", ["/some", "/other"])]
)
@pytest.mark.parametrize(
    "read_write",
    [
        ("", []),
        ("RW/", ["/"]),
        ("RW/some-write,RW/other-write", ["/some-write", "/other-write"]),
    ],
)
@pytest.mark.parametrize(
    "none",
    [("", []), ("N/", ["/"]), ("N/none,N/other-none", ["/none", "/other-none"])],
)
def test_parse_restrict_paths(
    read: Tuple[str, List[str]],
    read_write: Tuple[str, List[str]],
    none: Tuple[str, List[str]],
) -> None:
    rp = ",".join([r for r in [read[0], read_write[0], none[0]] if r])
    if rp:
        parsed: Optional[PathRestrictionsDict] = {
            "DATA_TYPE": "path_restrictions#1.0.0",
            "read": read[1],
            "read_write": read_write[1],
            "none": none[1],
        }
    else:
        parsed = None

    assert parse_restrict_paths(rp) == parsed
